@@ -18,7 +18,9 @@
  */
 
 #include "SpectacleCore.h"
+#include "SpectacleConfig.h"
 
+#include <QClipboard>
 #include <QDir>
 #include <QTimer>
 #include <QDebug>
@@ -81,9 +83,8 @@ SpectacleCore::SpectacleCore(StartMode startMode, ImageGrabber::GrabMode grabMod
     connect(this, &SpectacleCore::errorMessage, this, &SpectacleCore::showErrorMessage);
     connect(mImageGrabber, &ImageGrabber::pixmapChanged, this, &SpectacleCore::screenshotUpdated);
     connect(mImageGrabber, &ImageGrabber::imageGrabFailed, this, &SpectacleCore::screenshotFailed);
-    connect(mExportManager, &ExportManager::imageSaved, [&](const QUrl &savedAt) {
-        emit imageSaved(savedAt.toLocalFile());
-    });
+    connect(mExportManager, &ExportManager::imageSaved, this, &SpectacleCore::doCopyPath);
+    connect(mExportManager, &ExportManager::forceNotify, this, &SpectacleCore::doNotify);
 
     switch (startMode) {
     case DBusMode:
@@ -250,7 +251,6 @@ void SpectacleCore::doNotify(const QUrl &savedAt)
 
     connect(notify, &KNotification::action1Activated, this, [this, savedAt] {
         new KRun(savedAt, nullptr);
-
         QTimer::singleShot(250, this, &SpectacleCore::allDone);
     });
     connect(notify, &QObject::destroyed, this, &SpectacleCore::allDone);
@@ -258,6 +258,13 @@ void SpectacleCore::doNotify(const QUrl &savedAt)
     notify->sendEvent();
 }
 
+void SpectacleCore::doCopyPath(const QUrl &savedAt)
+{
+    if (SpectacleConfig::instance()->copySaveLocationToClipboard()) {
+        qApp->clipboard()->setText(savedAt.toLocalFile());
+    }
+}
+
 void SpectacleCore::doStartDragAndDrop()
 {
     QUrl tempFile = mExportManager->tempSave();
